summaryrefslogtreecommitdiffstats
path: root/tdecore/kextsock.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdecore/kextsock.h')
-rw-r--r--tdecore/kextsock.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/tdecore/kextsock.h b/tdecore/kextsock.h
index e733d8b45..095cc7a43 100644
--- a/tdecore/kextsock.h
+++ b/tdecore/kextsock.h
@@ -63,7 +63,7 @@ class KExtendedSocketPrivate;
* only difference is that the passiveSocket flag must be passed either to
* the constructor or to setSocketFlags(). If passiveSocket is used, the class will
* enable functions listen() and accept() and related signals, and will
- * also disable tqreadBlock() and tqwriteBlock().
+ * also disable readBlock() and writeBlock().
*
* To create a Unix socket, one would pass flag unixSocket to the constructor
* or setSocketFlags(). The hostname and service/port can be set to whatever is
@@ -668,7 +668,7 @@ public:
* ready to receive data, it will block, unless this is a non-blocking socket.
*
* This function does not touch the read buffer. You can empty it by calling
* tqreadBlock() with a null destination buffer.
*/
virtual void flush();
@@ -731,7 +731,7 @@ public:
* This function returns 0, if the function detected end-of-file condition
* (socket was closed)
*/
- virtual TQT_TQIO_LONG tqreadBlock(char *data, TQT_TQIO_ULONG maxlen);
+ virtual TQ_LONG readBlock(char *data, TQ_ULONG maxlen);
/**
* Writes a block of data to the socket.
@@ -756,7 +756,7 @@ public:
* The return value might be less than @p len if the output buffers cannot
* accommodate that many bytes and -1 in the case of an errro.
*/
- virtual TQT_TQIO_LONG tqwriteBlock(const char *data, TQT_TQIO_ULONG len);
+ virtual TQ_LONG writeBlock(const char *data, TQ_ULONG len);
/**
* Peeks at a block of data from the socket.
@@ -668,7 +668,7 @@ public:
*
* This function does not touch the read buffer. You can empty it by calling
- * tqreadBlock() with a null destination buffer.
+ * readBlock() with a null destination buffer.
*/
virtual void flush();